@@ -66,18 +66,18 @@ predict.timereg <-function(object,newdata=NULL,X=NULL,times=NULL,
                            Z=NULL,n.sim=500, uniform=TRUE,
                            se=TRUE,alpha=0.05,resample.iid=0,...)
 {
-    ## {{{
+## {{{
 ###    if (object$conv$convd>=1) stop("Model did not converge.")
+
  ### {{{ reading designs  and models 
   if (!(inherits(object,'comprisk') || inherits(object,'aalen')
         || inherits(object,'cox.aalen')))
-        stop ("Must be output from comp.risk function")
+        stop ("Must be output from comp.risk, aalen, cox.aalen, prop.odds function")
 
   if(inherits(object,'aalen')) { modelType <- 'aalen';
   } else if(inherits(object,'comprisk')) { modelType <- object$model;
   } else if(inherits(object,'cox.aalen')) { 
-	  if (is.null(object$prop.odds)) modelType <- 'cox.aalen' else  modelType <- 'prop.odds'; 
-	  
+	  if (object$prop.odds==0) modelType <- 'cox.aalen' else  modelType <- 'prop.odds'; 
   }
   type <- "na"
   if (modelType=="prop.odds")  type <- attr(object,'type')
@@ -147,6 +147,9 @@ predict.timereg <-function(object,newdata=NULL,X=NULL,times=NULL,
     ### SE based on iid decomposition so uses time-resolution for cox.aalen model 
     if (modelType=="cox.aalen" && (!is.null(object$time.sim.resolution)) && (se==TRUE)) 
     { iidtime <- object$time.sim.resolution; iidtimechange <- 1} 
+    ## prop.odds via cox.aalen
+    if (modelType=="prop.odds" && (!is.null(object$time.sim.resolution)) && (se==TRUE)) 
+    { iidtime <- object$time.sim.resolution; iidtimechange <- 1} 
 
     ## }}} 
   } else { ## {{{ 
@@ -276,8 +279,12 @@ predict.timereg <-function(object,newdata=NULL,X=NULL,times=NULL,
 	else if (modelType=="prop" || modelType=="rcif") { tmp<-RR*tmp+RR*tmp.const; } 
 	else if (modelType=="logistic" || modelType=="rcif2") { tmp<-RR*tmp+RR*cumhaz*tmp.const; } 
 	else if (modelType=="logistic2") { tmp<-RR*tmp+RR*cumhaz*tmp.const; } 
-	else if (modelType=="cox.aalen") { tmp <- RR * tmp + RR * cumhaz * tmp.const }
-	else if (modelType=="prop.odds") { tmp <- RR * tmp + RR * cumhaz * tmp.const; }
+	else if (modelType=="cox.aalen") {
+	       	tmp <- RR * tmp + RR * cumhaz * tmp.const }
+	else if (modelType=="prop.odds") {
+###		print(dim(RR)); print(dim(tmp)); 
+                tmp <- RR * tmp + RR * cumhaz * tmp.const; 
+	}
       } else {
 	if (modelType=="prop") { tmp<-RR*tmp; } 
       }
